==> cargo-binstall-1.15.11-1.src.tar.gz: cargo-binstall-1.15.11/crates/binstalk-git-repo-api/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.23...binstalk-git-repo-api-v0.5.24) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.22...binstalk-git-repo-api-v0.5.23) - 2025-07-25

### Other

- Disable unnecessary testing breaking ci ([#2228](https://github.com/cargo-bins/cargo-binstall/pull/2228))
- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.27...binstalk-git-repo-api-v0.5.28) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.26...binstalk-git-repo-api-v0.5.27) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.25...binstalk-git-repo-api-v0.5.26) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.5.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.24...binstalk-git-repo-api-v0.5.25) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.21...binstalk-git-repo-api-v0.5.22) - 2025-06-06

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.20...binstalk-git-repo-api-v0.5.21) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.19...binstalk-git-repo-api-v0.5.20) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.18...binstalk-git-repo-api-v0.5.19) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.17...binstalk-git-repo-api-v0.5.18) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.16...binstalk-git-repo-api-v0.5.17) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.5.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.15...binstalk-git-repo-api-v0.5.16) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.5.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.14...binstalk-git-repo-api-v0.5.15) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.13...binstalk-git-repo-api-v0.5.14) - 2025-02-11

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.12...binstalk-git-repo-api-v0.5.13) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.11...binstalk-git-repo-api-v0.5.12) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.5.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.10...binstalk-git-repo-api-v0.5.11) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.5.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.9...binstalk-git-repo-api-v0.5.10) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.5.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.8...binstalk-git-repo-api-v0.5.9) - 2025-01-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.7...binstalk-git-repo-api-v0.5.8) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.5.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.6...binstalk-git-repo-api-v0.5.7) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.5.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.5...binstalk-git-repo-api-v0.5.6) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.5.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.4...binstalk-git-repo-api-v0.5.5) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.5.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.3...binstalk-git-repo-api-v0.5.4) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.2...binstalk-git-repo-api-v0.5.3) - 2024-10-12

### Fixed

- *(gh_api_client)* remote client should never being shared everywhere because the underlying connection pool will be reused. ([#1930](https://github.com/cargo-bins/cargo-binstall/pull/1930))

### Other

- Fix binstalk-git-repo-api on PR of forks ([#1932](https://github.com/cargo-bins/cargo-binstall/pull/1932))

## [0.5.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.1...binstalk-git-repo-api-v0.5.2) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))

## [0.5.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.0...binstalk-git-repo-api-v0.5.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.4.0...binstalk-git-repo-api-v0.5.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

==> cargo-binstall-1.16.0-1.src.tar.gz: cargo-binstall-1.16.0/crates/binstalk-git-repo-api/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.23...binstalk-git-repo-api-v0.5.24) - 2025-08-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.22...binstalk-git-repo-api-v0.5.23) - 2025-07-25

### Other

- Disable unnecessary testing breaking ci ([#2228](https://github.com/cargo-bins/cargo-binstall/pull/2228))
- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.28...binstalk-git-repo-api-v0.5.29) - 2025-11-15

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.27...binstalk-git-repo-api-v0.5.28) - 2025-11-09

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.26...binstalk-git-repo-api-v0.5.27) - 2025-10-25

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.25...binstalk-git-repo-api-v0.5.26) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))

## [0.5.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.24...binstalk-git-repo-api-v0.5.25) - 2025-09-14

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.21...binstalk-git-repo-api-v0.5.22) - 2025-06-06

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.20...binstalk-git-repo-api-v0.5.21) - 2025-05-30

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.19...binstalk-git-repo-api-v0.5.20) - 2025-05-16

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.18...binstalk-git-repo-api-v0.5.19) - 2025-04-05

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.17...binstalk-git-repo-api-v0.5.18) - 2025-03-19

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.16...binstalk-git-repo-api-v0.5.17) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.5.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.15...binstalk-git-repo-api-v0.5.16) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.5.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.14...binstalk-git-repo-api-v0.5.15) - 2025-02-28

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.13...binstalk-git-repo-api-v0.5.14) - 2025-02-11

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.12...binstalk-git-repo-api-v0.5.13) - 2025-02-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.11...binstalk-git-repo-api-v0.5.12) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.5.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.10...binstalk-git-repo-api-v0.5.11) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.5.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.9...binstalk-git-repo-api-v0.5.10) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.5.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.8...binstalk-git-repo-api-v0.5.9) - 2025-01-04

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.7...binstalk-git-repo-api-v0.5.8) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.5.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.6...binstalk-git-repo-api-v0.5.7) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.5.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.5...binstalk-git-repo-api-v0.5.6) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.5.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.4...binstalk-git-repo-api-v0.5.5) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.5.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.3...binstalk-git-repo-api-v0.5.4) - 2024-11-02

### Other

- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.2...binstalk-git-repo-api-v0.5.3) - 2024-10-12

### Fixed

- *(gh_api_client)* remote client should never being shared everywhere because the underlying connection pool will be reused. ([#1930](https://github.com/cargo-bins/cargo-binstall/pull/1930))

### Other

- Fix binstalk-git-repo-api on PR of forks ([#1932](https://github.com/cargo-bins/cargo-binstall/pull/1932))

## [0.5.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.1...binstalk-git-repo-api-v0.5.2) - 2024-09-11

### Other

- report to new stats server (with status) ([#1912](https://github.com/cargo-bins/cargo-binstall/pull/1912))

## [0.5.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.5.0...binstalk-git-repo-api-v0.5.1) - 2024-08-12

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader

## [0.5.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-git-repo-api-v0.4.0...binstalk-git-repo-api-v0.5.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-downloader, binstalk-downloader
